@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,22 +15,24 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+import pkg_resources
 
 from google.cloud.container_v1.types import cluster_service
-from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-container",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-container",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -53,6 +55,7 @@ class ClusterManagerTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -79,10 +82,6 @@ class ClusterManagerTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -104,6 +103,11 @@ class ClusterManagerTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -116,6 +120,11 @@ class ClusterManagerTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -150,13 +159,19 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_cluster: gapic_v1.method.wrap_method(
-                self.create_cluster, default_timeout=45.0, client_info=client_info,
+                self.create_cluster,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.update_cluster: gapic_v1.method.wrap_method(
-                self.update_cluster, default_timeout=45.0, client_info=client_info,
+                self.update_cluster,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.update_node_pool: gapic_v1.method.wrap_method(
-                self.update_node_pool, default_timeout=45.0, client_info=client_info,
+                self.update_node_pool,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.set_node_pool_autoscaling: gapic_v1.method.wrap_method(
                 self.set_node_pool_autoscaling,
@@ -164,7 +179,9 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.set_logging_service: gapic_v1.method.wrap_method(
-                self.set_logging_service, default_timeout=45.0, client_info=client_info,
+                self.set_logging_service,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.set_monitoring_service: gapic_v1.method.wrap_method(
                 self.set_monitoring_service,
@@ -172,16 +189,24 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.set_addons_config: gapic_v1.method.wrap_method(
-                self.set_addons_config, default_timeout=45.0, client_info=client_info,
+                self.set_addons_config,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.set_locations: gapic_v1.method.wrap_method(
-                self.set_locations, default_timeout=45.0, client_info=client_info,
+                self.set_locations,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.update_master: gapic_v1.method.wrap_method(
-                self.update_master, default_timeout=45.0, client_info=client_info,
+                self.update_master,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.set_master_auth: gapic_v1.method.wrap_method(
-                self.set_master_auth, default_timeout=45.0, client_info=client_info,
+                self.set_master_auth,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.delete_cluster: gapic_v1.method.wrap_method(
                 self.delete_cluster,
@@ -229,7 +254,9 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.cancel_operation: gapic_v1.method.wrap_method(
-                self.cancel_operation, default_timeout=45.0, client_info=client_info,
+                self.cancel_operation,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.get_server_config: gapic_v1.method.wrap_method(
                 self.get_server_config,
@@ -247,7 +274,9 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_json_web_keys: gapic_v1.method.wrap_method(
-                self.get_json_web_keys, default_timeout=None, client_info=client_info,
+                self.get_json_web_keys,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_node_pools: gapic_v1.method.wrap_method(
                 self.list_node_pools,
@@ -280,7 +309,9 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_node_pool: gapic_v1.method.wrap_method(
-                self.create_node_pool, default_timeout=45.0, client_info=client_info,
+                self.create_node_pool,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.delete_node_pool: gapic_v1.method.wrap_method(
                 self.delete_node_pool,
@@ -297,6 +328,11 @@ class ClusterManagerTransport(abc.ABC):
                 default_timeout=20.0,
                 client_info=client_info,
             ),
+            self.complete_node_pool_upgrade: gapic_v1.method.wrap_method(
+                self.complete_node_pool_upgrade,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.rollback_node_pool_upgrade: gapic_v1.method.wrap_method(
                 self.rollback_node_pool_upgrade,
                 default_timeout=45.0,
@@ -308,13 +344,19 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.set_labels: gapic_v1.method.wrap_method(
-                self.set_labels, default_timeout=45.0, client_info=client_info,
+                self.set_labels,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.set_legacy_abac: gapic_v1.method.wrap_method(
-                self.set_legacy_abac, default_timeout=45.0, client_info=client_info,
+                self.set_legacy_abac,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.start_ip_rotation: gapic_v1.method.wrap_method(
-                self.start_ip_rotation, default_timeout=45.0, client_info=client_info,
+                self.start_ip_rotation,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.complete_ip_rotation: gapic_v1.method.wrap_method(
                 self.complete_ip_rotation,
@@ -322,10 +364,14 @@ class ClusterManagerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.set_node_pool_size: gapic_v1.method.wrap_method(
-                self.set_node_pool_size, default_timeout=45.0, client_info=client_info,
+                self.set_node_pool_size,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.set_network_policy: gapic_v1.method.wrap_method(
-                self.set_network_policy, default_timeout=45.0, client_info=client_info,
+                self.set_network_policy,
+                default_timeout=45.0,
+                client_info=client_info,
             ),
             self.set_maintenance_policy: gapic_v1.method.wrap_method(
                 self.set_maintenance_policy,
@@ -342,9 +388,9 @@ class ClusterManagerTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -558,6 +604,15 @@ class ClusterManagerTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def complete_node_pool_upgrade(
+        self,
+    ) -> Callable[
+        [cluster_service.CompleteNodePoolUpgradeRequest],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def rollback_node_pool_upgrade(
         self,
@@ -651,5 +706,9 @@ class ClusterManagerTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("ClusterManagerTransport",)
