@@ -75,6 +75,7 @@ from .cluster_service import (
     ListUsableSubnetworksResponse,
     LoggingComponentConfig,
     LoggingConfig,
+    LoggingVariantConfig,
     MaintenanceExclusionOptions,
     MaintenancePolicy,
     MaintenanceWindow,
@@ -99,6 +100,7 @@ from .cluster_service import (
     NodePoolAutoConfig,
     NodePoolAutoscaling,
     NodePoolDefaults,
+    NodePoolLoggingConfig,
     NodePoolUpdateStrategy,
     NodeTaint,
     NodeTaints,
@@ -210,6 +212,7 @@ __all__ = (
     "ListUsableSubnetworksResponse",
     "LoggingComponentConfig",
     "LoggingConfig",
+    "LoggingVariantConfig",
     "MaintenanceExclusionOptions",
     "MaintenancePolicy",
     "MaintenanceWindow",
@@ -234,6 +237,7 @@ __all__ = (
     "NodePoolAutoConfig",
     "NodePoolAutoscaling",
     "NodePoolDefaults",
+    "NodePoolLoggingConfig",
     "NodeTaint",
     "NodeTaints",
     "NotificationConfig",
