@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,20 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 
 from google.cloud.container_v1beta1.types import cluster_service
-from google.protobuf import empty_pb2  # type: ignore
-from .base import ClusterManagerTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, ClusterManagerTransport
 
 
 class ClusterManagerGrpcTransport(ClusterManagerTransport):
@@ -59,6 +58,7 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -154,6 +154,7 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -225,8 +226,7 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -851,6 +851,33 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
             )
         return self._stubs["delete_node_pool"]
 
+    @property
+    def complete_node_pool_upgrade(
+        self,
+    ) -> Callable[[cluster_service.CompleteNodePoolUpgradeRequest], empty_pb2.Empty]:
+        r"""Return a callable for the complete node pool upgrade method over gRPC.
+
+        CompleteNodePoolUpgrade will signal an on-going node
+        pool upgrade to complete.
+
+        Returns:
+            Callable[[~.CompleteNodePoolUpgradeRequest],
+                    ~.Empty]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "complete_node_pool_upgrade" not in self._stubs:
+            self._stubs["complete_node_pool_upgrade"] = self.grpc_channel.unary_unary(
+                "/google.container.v1beta1.ClusterManager/CompleteNodePoolUpgrade",
+                request_serializer=cluster_service.CompleteNodePoolUpgradeRequest.serialize,
+                response_deserializer=empty_pb2.Empty.FromString,
+            )
+        return self._stubs["complete_node_pool_upgrade"]
+
     @property
     def rollback_node_pool_upgrade(
         self,
@@ -1161,5 +1188,9 @@ class ClusterManagerGrpcTransport(ClusterManagerTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("ClusterManagerGrpcTransport",)
